pub struct LinuxTproxy;Implementations
Sourceimpl LinuxTproxy
impl LinuxTproxy
Sourcepub fn enable_tproxy(socket: &UdpSocket) -> Result<()>
pub fn enable_tproxy(socket: &UdpSocket) -> Result<()>
Enable IP_TRANSPARENT and IP_RECVORIGDSTADDR on the socket
Sourcepub fn create_transparent_udp_socket(addr: SocketAddr) -> Result<UdpSocket>
pub fn create_transparent_udp_socket(addr: SocketAddr) -> Result<UdpSocket>
Create a UDP socket bound to a specific address with IP_TRANSPARENT enabled. This allows binding to non-local addresses (spoofing source IP).
Sourcepub async fn recv_original_dst(
socket: &UdpSocket,
buf: &mut [u8],
) -> Result<(usize, SocketAddr, Option<SocketAddr>)>
pub async fn recv_original_dst( socket: &UdpSocket, buf: &mut [u8], ) -> Result<(usize, SocketAddr, Option<SocketAddr>)>
Receive a packet with original destination address Returns (bytes_read, source_addr, original_dest_addr)